import { CallbackSharedValueObject } from './CallbackSharedValueObject.js';
import { DateSharedValueObject } from './DateSharedValueObject.js';
import { EnumSharedValueObject } from './EnumSharedValueObject.js';
import { IdSharedValueObject } from './IdSharedValueObject.js';
import { NumberSharedValueObject } from './NumberSharedValueObject.js';
import { StringSharedValueObject } from './StringSharedValueObject.js';
var NO_OP = function NO_OP() {
  return null;
};
export var SharedValueObjectsFactory = function SharedValueObjectsFactory() {};
SharedValueObjectsFactory.callbackSharedValueObject = function (callback) {
  if (callback === void 0) {
    callback = NO_OP;
  }
  return new CallbackSharedValueObject({
    callback: callback
  });
};
SharedValueObjectsFactory.dateSharedValueObject = function (date) {
  if (date === void 0) {
    date = new Date();
  }
  return new DateSharedValueObject({
    date: date
  });
};
SharedValueObjectsFactory.enumSharedValueObject = function (availableValues, value) {
  var enumerated = new EnumSharedValueObject({
    availableValues: availableValues,
    value: value
  });
  enumerated.validate();
  return enumerated;
};
SharedValueObjectsFactory.idSharedValueObject = function (id) {
  if (id === void 0) {
    id = IdSharedValueObject.generateId();
  }
  return new IdSharedValueObject({
    id: id
  });
};
SharedValueObjectsFactory.stringSharedValueObject = function (string) {
  if (string === void 0) {
    string = '';
  }
  return new StringSharedValueObject({
    string: string
  });
};
SharedValueObjectsFactory.numberSharedValueObject = function (number) {
  if (number === void 0) {
    number = 0;
  }
  return new NumberSharedValueObject({
    number: number
  });
};