import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomProgressBar from '@s-ui/react-atom-progress-bar';
import MoleculeAccordion, { moleculeAccordionBehavior, MoleculeAccordionItem } from '@s-ui/react-molecule-accordion';
import { TaskManagerProvider } from './components/TaskManagerContext.js';
import useBeforeUnloadEffect from './hooks/useBeforeUnloadEffect.js';
import useContext from './hooks/useContext.js';
import useDevMode from './hooks/useDevMode.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
export default function ToolTaskManager(_ref) {
  var _ref$isVisible = _ref.isVisible,
    isVisible = _ref$isVisible === void 0 ? true : _ref$isVisible,
    _ref$statusIcons = _ref.statusIcons,
    statusIcons = _ref$statusIcons === void 0 ? {} : _ref$statusIcons;
  var _useContext = useContext(),
    countWork = _useContext.countWork,
    countFinishedWork = _useContext.countFinishedWork,
    getState = _useContext.getState;
  var state = getState();
  var _useDevMode = useDevMode(),
    isDevModeEnabled = _useDevMode.isDevModeEnabled,
    registerClick = _useDevMode.registerClick;
  useBeforeUnloadEffect({
    isVisible: isVisible
  });
  var getItems = function getItems() {
    return /*#__PURE__*/_jsx(_Fragment, {
      children: state.tasks.map(function (task) {
        if (task.visibleWork === 0 && isDevModeEnabled === false) return;
        var Icon = statusIcons[task.status] || '';
        var taskClassName = cx('sui-ToolTaskManager-task', "is-" + task.status.toLowerCase());
        var getLabel = function getLabel() {
          return /*#__PURE__*/_jsxs("div", {
            className: taskClassName,
            children: [/*#__PURE__*/_jsxs("div", {
              className: "sui-ToolTaskManager-taskInfo",
              children: [/*#__PURE__*/_jsx("div", {
                className: "sui-ToolTaskManager-taskIcon",
                children: Icon
              }), /*#__PURE__*/_jsx("div", {
                className: "sui-ToolTaskManager-taskName",
                children: task.name
              })]
            }), /*#__PURE__*/_jsxs("div", {
              className: "sui-ToolTaskManager-taskCounter",
              children: [countFinishedWork(task.id), " de ", countWork(task.id)]
            })]
          });
        };
        return /*#__PURE__*/_jsx(MoleculeAccordionItem, {
          value: task.id,
          label: getLabel(),
          content: /*#__PURE__*/_jsx(_Fragment, {
            children: task.work.map(function (work) {
              if (!work.isVisible && isDevModeEnabled === false) return;
              return /*#__PURE__*/_jsxs("div", {
                className: "sui-ToolTaskManager-work",
                children: [/*#__PURE__*/_jsxs("div", {
                  className: "sui-ToolTaskManager-workInfo",
                  children: [/*#__PURE__*/_jsx("span", {
                    className: "sui-ToolTaskManager-workInfoText",
                    children: work.name
                  }), /*#__PURE__*/_jsxs("span", {
                    children: [work.percentage, "%"]
                  })]
                }), /*#__PURE__*/_jsx("div", {
                  className: "sui-ToolTaskManager-workProgressBar",
                  children: /*#__PURE__*/_jsx(AtomProgressBar, {
                    hideIndicator: true,
                    percentage: work.percentage,
                    type: "line",
                    size: "medium"
                  })
                })]
              });
            })
          })
        }, task.id);
      })
    });
  };
  if (!isVisible) return null;

  // const existingTasks = isDevModeEnabled
  //   ? state.tasks.length
  //   : state.tasks.filter(task => task.visibleWork > 0).length

  return /*#__PURE__*/_jsx("div", {
    className: "sui-ToolTaskManager",
    onClick: registerClick,
    children: /*#__PURE__*/_jsx("div", {
      className: "sui-ToolTaskManager-container",
      children: /*#__PURE__*/_jsx(MoleculeAccordion, {
        as: "div",
        behavior: moleculeAccordionBehavior.MULTIPLE,
        children: /*#__PURE__*/_jsx(_Fragment, {
          children: getItems()
        })
      })
    })
  });
}
ToolTaskManager.displayName = 'ToolTaskManager';
export { TaskManagerProvider, useContext as useTaskManagerContext };